==> v1.2017.17.tar.gz: plantuml/src/net/sourceforge/plantuml/sequencediagram/MessageNumber.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2017, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.sequencediagram;

public class MessageNumber implements CharSequence {

	private final String representation;

	@Override
	public String toString() {
		return representation;
	}

	public MessageNumber(String s) {
		this.representation = s;
	}

	public String getNumber() {
		return representation;
	}

	public char charAt(int arg0) {
		return representation.charAt(arg0);
	}

	public int length() {
		return representation.length();
	}

	public CharSequence subSequence(int arg0, int arg1) {
		return representation.subSequence(arg0, arg1);
	}

}

==> v1.2021.4.tar.gz: plantuml/src/net/sourceforge/plantuml/sequencediagram/MessageNumber.java <==
/* ========================================================================
 * PlantUML : a free UML diagram generator
 * ========================================================================
 *
 * (C) Copyright 2009-2020, Arnaud Roques
 *
 * Project Info:  http://plantuml.com
 * 
 * If you like this project or if you find it useful, you can support us at:
 * 
 * http://plantuml.com/patreon (only 1$ per month!)
 * http://plantuml.com/paypal
 * 
 * This file is part of PlantUML.
 *
 * PlantUML is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * PlantUML distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
 * License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301,
 * USA.
 *
 *
 * Original Author:  Arnaud Roques
 * 
 *
 */
package net.sourceforge.plantuml.sequencediagram;

public class MessageNumber implements CharSequence {

	private final String representation;

	@Override
	public String toString() {
		return representation;
	}

	public MessageNumber(String s) {
		this.representation = s;
	}

	public String getNumberRaw() {
		return representation.replaceAll("\\</?b\\>", "");
	}

	public char charAt(int arg0) {
		return representation.charAt(arg0);
	}

	public int length() {
		return representation.length();
	}

	public CharSequence subSequence(int arg0, int arg1) {
		return representation.subSequence(arg0, arg1);
	}

}
